@@ -1,12 +1,9 @@
 from typing import Dict, List, Optional
 
-try:
-    from typing import Literal, TypedDict
-except ImportError:
-    from typing_extensions import Literal, TypedDict  # type: ignore
+from typing_extensions import Literal, TypedDict
 
 
-class SQSAttributesDict(TypedDict):
+class SQSAttributesDict(TypedDict, total=False):
     ApproximateFirstReceiveTimestamp: int
     ApproximateReceiveCount: int
     MessageDeduplicationId: Optional[int]
